========================================
Sample networking_ovn_metadata_agent.ini
========================================

This sample configuration can also be viewed in `the raw format
<../../_static/config_samples/networking_ovn_metadata_agent.conf.sample>`_.

.. literalinclude::
   ../../_static/config_samples/networking_ovn_metadata_agent.conf.sample
